@@ -22,6 +22,10 @@ from LivestockCV.core import roi
 from LivestockCV.core import threshold
 from LivestockCV.core.gaussian_blur import gaussian_blur
 from LivestockCV.core.analyze_color import analyze_color
+from LivestockCV.core.frame_count import frame_count
+from LivestockCV.core import js_to_image
+from LivestockCV.core import bbox_to_bytes
+from LivestockCV.core import take_photo
 # add new functions to end of lists
 
 # Auto versioning
@@ -29,4 +33,4 @@ from ._version import get_versions
 __version__ = get_versions()['version']
 del get_versions
 
-__all__ = ['fatal_error', 'Params', 'Outputs', 'deprecation_warning', 'print_image', 'plot_image', 'color_palette', 'rgb2gray', 'rgb2gray_hsv', 'rgb2gray_lab', 'transform', 'apply_mask', 'crop', 'invert', 'roi', 'threshold', 'gaussian_blur', 'analyze_color']
+__all__ = ['fatal_error', 'Params', 'Outputs', 'deprecation_warning', 'print_image', 'plot_image', 'color_palette', 'rgb2gray', 'rgb2gray_hsv', 'rgb2gray_lab', 'transform', 'apply_mask', 'crop', 'invert', 'roi', 'threshold', 'gaussian_blur', 'analyze_color', 'frame_count', 'js_to_image', 'bbox_to_bytes','take_photo']
