@@ -9,25 +9,7 @@ from LivestockCV.core import params
 
 
 def crop(img, x, y, h, w):
-    """Crop image.
 
-       Inputs:
-       img       = RGB, grayscale, or hyperspectral image data
-       x         = X coordinate of starting point
-       y         = Y coordinate of starting point
-       h         = Height
-       w         = Width
-
-       Returns:
-       cropped   = cropped image
-
-       :param img: numpy.ndarray
-       :param x: int
-       :param y: int
-       :param h: int
-       :param w: int
-       :return cropped: numpy.ndarray
-       """
     params.device += 1
 
     # Check if the array data format
